pub struct CallError(String);Expand description
The call failed before it could return a value. This should not happen unless
the thread panics, which can only happen if the function passed to run_in_thread
panics.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Error for CallError
impl Error for CallError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()